\name{predict.rpudl}
\alias{predict.rpudl}
\concept{deep learning}

\title{
Predictions of an RPUDL Model
}

\description{
Predict the classification outcome of a collection of input vectors
based on a trained RPUDL model.
}

\usage{
\method{predict}{rpudl}(
    model,
    x,
    ...,
    log.level = 1
    )
}

\arguments{
  \item{model}{a trained \code{rpudl} model object for prediction}
  \item{x}{An m by n matrix, where m is the size of each input vector,
        and n is the number of input vectors} 
  \item{\dots}{further arguments to be passed to or from methods}
  \item{log.level}{level of the method output (0 = silent, 
        1 = basic output, 2 = detailed output)} 
}

\value{
A vector whose length is the number of input vectors.
the 'i-th' entry in the vector is the prediction class 
of the 'i-th' input vector.
The probability output of each input vector is stored in the 
\code{"decision.values"}.
}

\author{
  Chi Yau\cr
  \email{chi.yau@r-tutor.com}
}

\seealso{
rpudl,\cr
rpudlDataSource,\cr
rpudlTestDataSample,\cr
rpudlTrain
}

\examples{
\dontrun{
# create data source
ds <- rpudlDataSource(
        data.format="lmdb",
        data.dir="data/mnist",
        train.data="mnist-official-data_train_lmdb",
        test.data="mnist-official-data_test_lmdb",
        data.shape=c(28, 28)
)

# create model
model <- rpudl(
        "mnist_mpl_lenet.prototxt",
        data.source=ds
)   

# train model
model <- rpudlTrain(model, batch=100, iter=1000)

# extract some test samples
num <- 12
obj <- rpudlTestDataSample(ds, c(1, num))

# predictions
res <- predict(model, obj$x)

# find num of errors
sum((obj$y+1) == res)
}}

\keyword{misc}


