\name{rpudlPretrain}
\alias{rpudlPretrain}
\concept{deep learning}

\title{
RPUDL Model Pre-training 
}

\description{
Pre-train a \code{RPUDL} deep learning model.
}

\details{
Only the fully-connected layers will be pre-trained via one of the following mechanisms:
\itemize{ 
  \item{Masked autoencoder}{}
  \item{Gaussian autoencoder}{}
  \item{Restricted Boltzmann Machine}{}
}}

\usage{
rpudlPretrain(
    model,
    learning.rate = 0,
    batch.size = 128,
    iterations = 128,
    display = 100,
    seed = 0,
    ...,
    log.level = 1
    )
}

\arguments{
  \item{model}{a \code{rpudl} model object to be pre-trained}
  \item{learning.rate}{manual override of the learning rate, ignored if zero or negative}
  \item{batch.size}{the size of a data batch for each training iteration}
  \item{iterations}{maximum number of training iterations}
  \item{display}{a logical to display training progress}
  \item{seed}{seed of random number generation}
  \item{\dots}{further arguments to be passed to or from methods}
  \item{log.level}{level of the method output (0 = silent, 
        1 = basic output, 2 = detailed output)} 
}

\value{
  An \code{rpudl} object with pre-trained parameters.
}

\author{
  Chi Yau\cr
  \email{chi.yau@r-tutor.com}
}

\seealso{
  rpudl,\cr
  rpudlTrain,\cr
  rpudlPredict,
}

\examples{
\dontrun{
# create data source
ds <- rpudlCreateDataSource(
        data.format="lmdb",
        data.dir="data/mnist",
        train.data="mnist-official-data_train_lmdb",
        test.data="mnist-official-data_test_lmdb",
        data.shape=c(28, 28)
)

# create model
model <- rpudl(
        "masked_autoencoder.prototxt",
        data.source=ds
)   

# pre-train
model <- rpudlPretrain(model, batch=100, iter=1000)
}}

\keyword{misc}


